@@ -11,6 +11,7 @@ try:
     from . import exceptions
     from . import command
     from . import check_value
+    from . import _api_util
 except ModuleNotFoundError:
     import data_type
     import i18n
@@ -20,6 +21,7 @@ except ModuleNotFoundError:
     import exceptions
     import command
     import check_value
+    import _api_util
 
 
 def _get_newest_index(api) -> int:
@@ -186,9 +188,8 @@ def get_newest_index(
         cmd_list.append(command.GoMainMenu)
         cmd_list.append(command.Ctrl_Z)
         cmd_list.append('m')
-        cmd_list.append('1')
-        cmd_list.append(command.Enter)
-        cmd_list.append('$')
+        cmd_list.append(command.Ctrl_F * 50)
+
         cmd = ''.join(cmd_list)
 
         target_list = [
@@ -196,24 +197,38 @@ def get_newest_index(
                 i18n.MailBox,
                 screens.Target.InMailBox,
                 break_detect=True,
-                log_level=log.level.DEBUG
+                # log_level=log.level.DEBUG
             ),
             connect_core.TargetUnit(
                 i18n.NoMail,
-                screens.Target.MainMenu,
+                screens.Target.CursorToGoodbye,
                 break_detect=True,
                 log_level=log.level.DEBUG
-            )
+            ),
         ]
 
-        index = api.connect_core.send(
-            cmd,
-            target_list,
-        )
+        def get_index(api):
+            current_capacity, _ = _api_util.get_mailbox_capacity(api)
+            last_screen = api.connect_core.get_screen_queue()[-1]
+            cursor_line = [x for x in last_screen.split('\n') if x.strip().startswith(api.cursor)][0]
+            # print(cursor_line)
+            list_index = int(re.compile('(\d+)').search(cursor_line).group(0))
+            if list_index > current_capacity:
+                newest_index = list_index
+            else:
+                newest_index = current_capacity
 
-        if index == 1:
-            return 0
+            return newest_index
 
-        newest_index = _get_newest_index(api)
+        for _ in range(3):
+            index = api.connect_core.send(
+                cmd,
+                target_list,
+            )
+
+            if index == 0:
+                newest_index = get_index(api)
+                break
+            newest_index = 0
 
     return newest_index
